@@ -14,7 +14,6 @@ pub use self::{
     diagnostic_builder::DiagnosticBuilder,
     emitter::{ColorConfig, Emitter, EmitterWriter},
 };
-#[cfg(feature = "tty-emitter")]
 use crate::sync::Lrc;
 use crate::{
     rustc_data_structures::stable_hasher::StableHasher,
@@ -25,7 +24,9 @@ use std::{
     borrow::Cow,
     cell::RefCell,
     collections::HashSet,
-    error, fmt, panic,
+    error, fmt,
+    io::Write,
+    panic,
     sync::atomic::{AtomicUsize, Ordering::SeqCst},
 };
 #[cfg(feature = "tty-emitter")]
@@ -359,13 +360,14 @@ impl Handler {
         Handler::with_emitter_and_flags(emitter, flags)
     }
 
+    /// Example implementation of [Emitter] is [EmitterWriter]
     pub fn with_emitter(
         can_emit_warnings: bool,
         treat_err_as_bug: bool,
-        e: Box<dyn Emitter + Send>,
+        emitter: Box<dyn Emitter>,
     ) -> Handler {
         Handler::with_emitter_and_flags(
-            e,
+            emitter,
             HandlerFlags {
                 can_emit_warnings,
                 treat_err_as_bug,
@@ -374,6 +376,18 @@ impl Handler {
         )
     }
 
+    /// Calls [Self::with_emitter] with [EmitterWriter].
+    pub fn with_emitter_writer(
+        dst: Box<dyn Write + Send>,
+        cm: Option<Lrc<SourceMapperDyn>>,
+    ) -> Handler {
+        Handler::with_emitter(
+            true,
+            false,
+            Box::new(EmitterWriter::new(dst, cm, false, true)),
+        )
+    }
+
     pub fn with_emitter_and_flags(e: Box<dyn Emitter>, flags: HandlerFlags) -> Handler {
         Handler {
             flags,
